// ----------------------------------------------------------------------------------------------
// Copyright (c) fulesnabel@hotmail.se
// ----------------------------------------------------------------------------------------------
// This source code is subject to terms and conditions of the Microsoft Public License. A 
// copy of the license can be found in the License.html file at the root of this distribution. 
// If you cannot locate the  Microsoft Public License, please send an email to 
// dlr@microsoft.com. By using this source code in any fashion, you are agreeing to be bound 
//  by the terms of the Microsoft Public License.
// ----------------------------------------------------------------------------------------------
// You must not remove this notice, or any other, from this software.
// ----------------------------------------------------------------------------------------------

namespace SBFastGraphics.Internal
{
    using System;
    using System.Threading;

    abstract class BaseDisposable : IDisposable
    {
        int m_isDisposed;

        public bool IsDisposed
        {
            get
            {
                return m_isDisposed != 0;
            }
        }

        public void Dispose ()
        {
            try
            {
                if (Interlocked.Exchange (ref m_isDisposed, 1) == 0)
                {
                    OnDispose ();
                }
            }
            catch (Exception exc)
            {
                Log.Error ("Failed to dispose {0}: {1}", GetType ().FullName, exc);
            }
        }

        protected abstract void OnDispose ();
    }
}