﻿// ----------------------------------------------------------------------------------------------
// Copyright (c) fulesnabel@hotmail.se
// ----------------------------------------------------------------------------------------------
// This source code is subject to terms and conditions of the Microsoft Public License. A 
// copy of the license can be found in the License.html file at the root of this distribution. 
// If you cannot locate the  Microsoft Public License, please send an email to 
// dlr@microsoft.com. By using this source code in any fashion, you are agreeing to be bound 
//  by the terms of the Microsoft Public License.
// ----------------------------------------------------------------------------------------------
// You must not remove this notice, or any other, from this software.
// ----------------------------------------------------------------------------------------------

namespace SBFastGraphics.Internal
{
    using System;
    using System.Collections.Generic;
    using System.Diagnostics;
    using System.Linq;

    static class EnumParser<TEnum>
        where TEnum : struct
    {
        static readonly Dictionary<string, TEnum> s_values;

        static EnumParser ()
        {
            var type = typeof (TEnum);
            Debug.Assert (type.IsEnum);
            if (!type.IsEnum)
            {
                s_values = new Dictionary<string, TEnum> ();
                return;
            }

            var names = Enum.GetNames (type);
            var values = Enum.GetValues (type).Cast<TEnum> ().ToArray ();

            Debug.Assert (names.Length == values.Length);

            s_values = Enumerable
                .Range (0, Math.Min (names.Length, values.Length))
                .ToDictionary (i => names[i].ToLowerInvariant (), i => values[i])
                ;
        }

        public static bool TryParse (string s, out TEnum value)
        {
            return s_values.TryGetValue ((s ?? "").ToLowerInvariant (), out value);
        }

    }
}
