﻿// ----------------------------------------------------------------------------------------------
// Copyright (c) fulesnabel@hotmail.se
// ----------------------------------------------------------------------------------------------
// This source code is subject to terms and conditions of the Microsoft Public License. A 
// copy of the license can be found in the License.html file at the root of this distribution. 
// If you cannot locate the  Microsoft Public License, please send an email to 
// dlr@microsoft.com. By using this source code in any fashion, you are agreeing to be bound 
//  by the terms of the Microsoft Public License.
// ----------------------------------------------------------------------------------------------
// You must not remove this notice, or any other, from this software.
// ----------------------------------------------------------------------------------------------


// ReSharper disable EmptyConstructor
// ReSharper disable PartialMethodWithSinglePart
// ReSharper disable PartialTypeWithSinglePart


// ReSharper disable RedundantThisQualifier

namespace SBFastGraphics.Internal
{
    using System.Text;
    using Interfaces;


    // ------------------------------------------------------------------------
    // RemoveResource message
    // ------------------------------------------------------------------------
    sealed partial class RemoveResource 
        :   IMessage
/*
*/        
    {
        public int MessageTypeId 
        { 
            get
            {
                return 1;
            }
        }

        public void Apply (IMessageVisitor messageVisitor)
        {
            messageVisitor.Visit (this);
        }
        
        public RemoveResource (
                string name
            )
        {
            this.Name = name;
        }

        public string Name;

#if DEBUG
        public override string ToString ()
        {
            var sb = new StringBuilder ("{RemoveResource");

            sb.Append (" ; Name = ");
            sb.Append (Name);

            sb.Append ("}");
            return sb.ToString ();
        }
#endif
    }
    // ------------------------------------------------------------------------

    // ------------------------------------------------------------------------
    // RemoveAllResources message
    // ------------------------------------------------------------------------
    sealed partial class RemoveAllResources 
        :   IMessage
/*
*/        
    {
        public int MessageTypeId 
        { 
            get
            {
                return 2;
            }
        }

        public void Apply (IMessageVisitor messageVisitor)
        {
            messageVisitor.Visit (this);
        }
        
        public RemoveAllResources (
                string name
            )
        {
            this.Name = name;
        }

        public string Name;

#if DEBUG
        public override string ToString ()
        {
            var sb = new StringBuilder ("{RemoveAllResources");

            sb.Append (" ; Name = ");
            sb.Append (Name);

            sb.Append ("}");
            return sb.ToString ();
        }
#endif
    }
    // ------------------------------------------------------------------------

    // ------------------------------------------------------------------------
    // Remove message
    // ------------------------------------------------------------------------
    sealed partial class Remove 
        :   IMessage
/*
*/        
    {
        public int MessageTypeId 
        { 
            get
            {
                return 3;
            }
        }

        public void Apply (IMessageVisitor messageVisitor)
        {
            messageVisitor.Visit (this);
        }
        
        public Remove (
                string name
            )
        {
            this.Name = name;
        }

        public string Name;

#if DEBUG
        public override string ToString ()
        {
            var sb = new StringBuilder ("{Remove");

            sb.Append (" ; Name = ");
            sb.Append (Name);

            sb.Append ("}");
            return sb.ToString ();
        }
#endif
    }
    // ------------------------------------------------------------------------

    // ------------------------------------------------------------------------
    // RemoveAll message
    // ------------------------------------------------------------------------
    sealed partial class RemoveAll 
        :   IMessage
/*
*/        
    {
        public int MessageTypeId 
        { 
            get
            {
                return 4;
            }
        }

        public void Apply (IMessageVisitor messageVisitor)
        {
            messageVisitor.Visit (this);
        }
        
        public RemoveAll (
                string name
            )
        {
            this.Name = name;
        }

        public string Name;

#if DEBUG
        public override string ToString ()
        {
            var sb = new StringBuilder ("{RemoveAll");

            sb.Append (" ; Name = ");
            sb.Append (Name);

            sb.Append ("}");
            return sb.ToString ();
        }
#endif
    }
    // ------------------------------------------------------------------------

    // ------------------------------------------------------------------------
    // WindowSize message
    // ------------------------------------------------------------------------
    sealed partial class WindowSize 
        :   IMessage
/*
*/        
    {
        public int MessageTypeId 
        { 
            get
            {
                return 5;
            }
        }

        public void Apply (IMessageVisitor messageVisitor)
        {
            messageVisitor.Visit (this);
        }
        
        public WindowSize (
                int width
            ,   int height
            )
        {
            this.Width = width;
            this.Height = height;
        }

        public int Width;
        public int Height;

#if DEBUG
        public override string ToString ()
        {
            var sb = new StringBuilder ("{WindowSize");

            sb.Append (" ; Width = ");
            sb.Append (Width);
            sb.Append (" ; Height = ");
            sb.Append (Height);

            sb.Append ("}");
            return sb.ToString ();
        }
#endif
    }
    // ------------------------------------------------------------------------

    // ------------------------------------------------------------------------
    // WindowBackground message
    // ------------------------------------------------------------------------
    sealed partial class WindowBackground 
        :   IMessage
/*
*/        
    {
        public int MessageTypeId 
        { 
            get
            {
                return 6;
            }
        }

        public void Apply (IMessageVisitor messageVisitor)
        {
            messageVisitor.Visit (this);
        }
        
        public WindowBackground (
                string color
            )
        {
            this.Color = color;
        }

        public string Color;

#if DEBUG
        public override string ToString ()
        {
            var sb = new StringBuilder ("{WindowBackground");

            sb.Append (" ; Color = ");
            sb.Append (Color);

            sb.Append ("}");
            return sb.ToString ();
        }
#endif
    }
    // ------------------------------------------------------------------------

    // ------------------------------------------------------------------------
    // Line message
    // ------------------------------------------------------------------------
    sealed partial class Line 
        :   IMessage
/*
        ,   IRenderable
*/        
    {
        public int MessageTypeId 
        { 
            get
            {
                return 7;
            }
        }

        public void Apply (IMessageVisitor messageVisitor)
        {
            messageVisitor.Visit (this);
        }
        
        public Line (
                string name
            ,   string brush
            ,   float thickness
            ,   float opacity
            ,   float x0
            ,   float y0
            ,   float x1
            ,   float y1
            )
        {
            this.Name = name;
            this.Brush = brush;
            this.Thickness = thickness;
            this.Opacity = opacity;
            this.X0 = x0;
            this.Y0 = y0;
            this.X1 = x1;
            this.Y1 = y1;
        }

        public string Name;
        public string Brush;
        public float Thickness;
        public float Opacity;
        public float X0;
        public float Y0;
        public float X1;
        public float Y1;

#if DEBUG
        public override string ToString ()
        {
            var sb = new StringBuilder ("{Line");

            sb.Append (" ; Name = ");
            sb.Append (Name);
            sb.Append (" ; Brush = ");
            sb.Append (Brush);
            sb.Append (" ; Thickness = ");
            sb.Append (Thickness);
            sb.Append (" ; Opacity = ");
            sb.Append (Opacity);
            sb.Append (" ; X0 = ");
            sb.Append (X0);
            sb.Append (" ; Y0 = ");
            sb.Append (Y0);
            sb.Append (" ; X1 = ");
            sb.Append (X1);
            sb.Append (" ; Y1 = ");
            sb.Append (Y1);

            sb.Append ("}");
            return sb.ToString ();
        }
#endif
    }
    // ------------------------------------------------------------------------

    // ------------------------------------------------------------------------
    // Rectangle message
    // ------------------------------------------------------------------------
    sealed partial class Rectangle 
        :   IMessage
/*
        ,   IRenderable
*/        
    {
        public int MessageTypeId 
        { 
            get
            {
                return 8;
            }
        }

        public void Apply (IMessageVisitor messageVisitor)
        {
            messageVisitor.Visit (this);
        }
        
        public Rectangle (
                string name
            ,   string brush
            ,   float opacity
            ,   float x
            ,   float y
            ,   float width
            ,   float height
            ,   float thickness
            )
        {
            this.Name = name;
            this.Brush = brush;
            this.Opacity = opacity;
            this.X = x;
            this.Y = y;
            this.Width = width;
            this.Height = height;
            this.Thickness = thickness;
        }

        public string Name;
        public string Brush;
        public float Opacity;
        public float X;
        public float Y;
        public float Width;
        public float Height;
        public float Thickness;

#if DEBUG
        public override string ToString ()
        {
            var sb = new StringBuilder ("{Rectangle");

            sb.Append (" ; Name = ");
            sb.Append (Name);
            sb.Append (" ; Brush = ");
            sb.Append (Brush);
            sb.Append (" ; Opacity = ");
            sb.Append (Opacity);
            sb.Append (" ; X = ");
            sb.Append (X);
            sb.Append (" ; Y = ");
            sb.Append (Y);
            sb.Append (" ; Width = ");
            sb.Append (Width);
            sb.Append (" ; Height = ");
            sb.Append (Height);
            sb.Append (" ; Thickness = ");
            sb.Append (Thickness);

            sb.Append ("}");
            return sb.ToString ();
        }
#endif
    }
    // ------------------------------------------------------------------------

    // ------------------------------------------------------------------------
    // RoundedRectangle message
    // ------------------------------------------------------------------------
    sealed partial class RoundedRectangle 
        :   IMessage
/*
        ,   IRenderable
*/        
    {
        public int MessageTypeId 
        { 
            get
            {
                return 9;
            }
        }

        public void Apply (IMessageVisitor messageVisitor)
        {
            messageVisitor.Visit (this);
        }
        
        public RoundedRectangle (
                string name
            ,   string brush
            ,   float opacity
            ,   float x
            ,   float y
            ,   float width
            ,   float height
            ,   float radiusX
            ,   float radiusY
            ,   float thickness
            )
        {
            this.Name = name;
            this.Brush = brush;
            this.Opacity = opacity;
            this.X = x;
            this.Y = y;
            this.Width = width;
            this.Height = height;
            this.RadiusX = radiusX;
            this.RadiusY = radiusY;
            this.Thickness = thickness;
        }

        public string Name;
        public string Brush;
        public float Opacity;
        public float X;
        public float Y;
        public float Width;
        public float Height;
        public float RadiusX;
        public float RadiusY;
        public float Thickness;

#if DEBUG
        public override string ToString ()
        {
            var sb = new StringBuilder ("{RoundedRectangle");

            sb.Append (" ; Name = ");
            sb.Append (Name);
            sb.Append (" ; Brush = ");
            sb.Append (Brush);
            sb.Append (" ; Opacity = ");
            sb.Append (Opacity);
            sb.Append (" ; X = ");
            sb.Append (X);
            sb.Append (" ; Y = ");
            sb.Append (Y);
            sb.Append (" ; Width = ");
            sb.Append (Width);
            sb.Append (" ; Height = ");
            sb.Append (Height);
            sb.Append (" ; RadiusX = ");
            sb.Append (RadiusX);
            sb.Append (" ; RadiusY = ");
            sb.Append (RadiusY);
            sb.Append (" ; Thickness = ");
            sb.Append (Thickness);

            sb.Append ("}");
            return sb.ToString ();
        }
#endif
    }
    // ------------------------------------------------------------------------

    // ------------------------------------------------------------------------
    // FilledRoundedRectangle message
    // ------------------------------------------------------------------------
    sealed partial class FilledRoundedRectangle 
        :   IMessage
/*
        ,   IRenderable
*/        
    {
        public int MessageTypeId 
        { 
            get
            {
                return 10;
            }
        }

        public void Apply (IMessageVisitor messageVisitor)
        {
            messageVisitor.Visit (this);
        }
        
        public FilledRoundedRectangle (
                string name
            ,   string brush
            ,   float opacity
            ,   float x
            ,   float y
            ,   float width
            ,   float height
            ,   float radiusX
            ,   float radiusY
            )
        {
            this.Name = name;
            this.Brush = brush;
            this.Opacity = opacity;
            this.X = x;
            this.Y = y;
            this.Width = width;
            this.Height = height;
            this.RadiusX = radiusX;
            this.RadiusY = radiusY;
        }

        public string Name;
        public string Brush;
        public float Opacity;
        public float X;
        public float Y;
        public float Width;
        public float Height;
        public float RadiusX;
        public float RadiusY;

#if DEBUG
        public override string ToString ()
        {
            var sb = new StringBuilder ("{FilledRoundedRectangle");

            sb.Append (" ; Name = ");
            sb.Append (Name);
            sb.Append (" ; Brush = ");
            sb.Append (Brush);
            sb.Append (" ; Opacity = ");
            sb.Append (Opacity);
            sb.Append (" ; X = ");
            sb.Append (X);
            sb.Append (" ; Y = ");
            sb.Append (Y);
            sb.Append (" ; Width = ");
            sb.Append (Width);
            sb.Append (" ; Height = ");
            sb.Append (Height);
            sb.Append (" ; RadiusX = ");
            sb.Append (RadiusX);
            sb.Append (" ; RadiusY = ");
            sb.Append (RadiusY);

            sb.Append ("}");
            return sb.ToString ();
        }
#endif
    }
    // ------------------------------------------------------------------------

    // ------------------------------------------------------------------------
    // FilledRectangle message
    // ------------------------------------------------------------------------
    sealed partial class FilledRectangle 
        :   IMessage
/*
        ,   IRenderable
*/        
    {
        public int MessageTypeId 
        { 
            get
            {
                return 11;
            }
        }

        public void Apply (IMessageVisitor messageVisitor)
        {
            messageVisitor.Visit (this);
        }
        
        public FilledRectangle (
                string name
            ,   string brush
            ,   float opacity
            ,   float x
            ,   float y
            ,   float width
            ,   float height
            )
        {
            this.Name = name;
            this.Brush = brush;
            this.Opacity = opacity;
            this.X = x;
            this.Y = y;
            this.Width = width;
            this.Height = height;
        }

        public string Name;
        public string Brush;
        public float Opacity;
        public float X;
        public float Y;
        public float Width;
        public float Height;

#if DEBUG
        public override string ToString ()
        {
            var sb = new StringBuilder ("{FilledRectangle");

            sb.Append (" ; Name = ");
            sb.Append (Name);
            sb.Append (" ; Brush = ");
            sb.Append (Brush);
            sb.Append (" ; Opacity = ");
            sb.Append (Opacity);
            sb.Append (" ; X = ");
            sb.Append (X);
            sb.Append (" ; Y = ");
            sb.Append (Y);
            sb.Append (" ; Width = ");
            sb.Append (Width);
            sb.Append (" ; Height = ");
            sb.Append (Height);

            sb.Append ("}");
            return sb.ToString ();
        }
#endif
    }
    // ------------------------------------------------------------------------

    // ------------------------------------------------------------------------
    // Ellipse message
    // ------------------------------------------------------------------------
    sealed partial class Ellipse 
        :   IMessage
/*
        ,   IRenderable
*/        
    {
        public int MessageTypeId 
        { 
            get
            {
                return 12;
            }
        }

        public void Apply (IMessageVisitor messageVisitor)
        {
            messageVisitor.Visit (this);
        }
        
        public Ellipse (
                string name
            ,   string brush
            ,   float opacity
            ,   float centerX
            ,   float centerY
            ,   float radiusX
            ,   float radiusY
            ,   float thickness
            )
        {
            this.Name = name;
            this.Brush = brush;
            this.Opacity = opacity;
            this.CenterX = centerX;
            this.CenterY = centerY;
            this.RadiusX = radiusX;
            this.RadiusY = radiusY;
            this.Thickness = thickness;
        }

        public string Name;
        public string Brush;
        public float Opacity;
        public float CenterX;
        public float CenterY;
        public float RadiusX;
        public float RadiusY;
        public float Thickness;

#if DEBUG
        public override string ToString ()
        {
            var sb = new StringBuilder ("{Ellipse");

            sb.Append (" ; Name = ");
            sb.Append (Name);
            sb.Append (" ; Brush = ");
            sb.Append (Brush);
            sb.Append (" ; Opacity = ");
            sb.Append (Opacity);
            sb.Append (" ; CenterX = ");
            sb.Append (CenterX);
            sb.Append (" ; CenterY = ");
            sb.Append (CenterY);
            sb.Append (" ; RadiusX = ");
            sb.Append (RadiusX);
            sb.Append (" ; RadiusY = ");
            sb.Append (RadiusY);
            sb.Append (" ; Thickness = ");
            sb.Append (Thickness);

            sb.Append ("}");
            return sb.ToString ();
        }
#endif
    }
    // ------------------------------------------------------------------------

    // ------------------------------------------------------------------------
    // FilledEllipse message
    // ------------------------------------------------------------------------
    sealed partial class FilledEllipse 
        :   IMessage
/*
        ,   IRenderable
*/        
    {
        public int MessageTypeId 
        { 
            get
            {
                return 13;
            }
        }

        public void Apply (IMessageVisitor messageVisitor)
        {
            messageVisitor.Visit (this);
        }
        
        public FilledEllipse (
                string name
            ,   string brush
            ,   float opacity
            ,   float centerX
            ,   float centerY
            ,   float radiusX
            ,   float radiusY
            )
        {
            this.Name = name;
            this.Brush = brush;
            this.Opacity = opacity;
            this.CenterX = centerX;
            this.CenterY = centerY;
            this.RadiusX = radiusX;
            this.RadiusY = radiusY;
        }

        public string Name;
        public string Brush;
        public float Opacity;
        public float CenterX;
        public float CenterY;
        public float RadiusX;
        public float RadiusY;

#if DEBUG
        public override string ToString ()
        {
            var sb = new StringBuilder ("{FilledEllipse");

            sb.Append (" ; Name = ");
            sb.Append (Name);
            sb.Append (" ; Brush = ");
            sb.Append (Brush);
            sb.Append (" ; Opacity = ");
            sb.Append (Opacity);
            sb.Append (" ; CenterX = ");
            sb.Append (CenterX);
            sb.Append (" ; CenterY = ");
            sb.Append (CenterY);
            sb.Append (" ; RadiusX = ");
            sb.Append (RadiusX);
            sb.Append (" ; RadiusY = ");
            sb.Append (RadiusY);

            sb.Append ("}");
            return sb.ToString ();
        }
#endif
    }
    // ------------------------------------------------------------------------

    // ------------------------------------------------------------------------
    // Bitmap message
    // ------------------------------------------------------------------------
    sealed partial class Bitmap 
        :   IMessage
/*
        ,   IRenderable
*/        
    {
        public int MessageTypeId 
        { 
            get
            {
                return 14;
            }
        }

        public void Apply (IMessageVisitor messageVisitor)
        {
            messageVisitor.Visit (this);
        }
        
        public Bitmap (
                string name
            ,   string bitmapName
            ,   float opacity
            ,   float x
            ,   float y
            ,   float width
            ,   float height
            )
        {
            this.Name = name;
            this.BitmapName = bitmapName;
            this.Opacity = opacity;
            this.X = x;
            this.Y = y;
            this.Width = width;
            this.Height = height;
        }

        public string Name;
        public string BitmapName;
        public float Opacity;
        public float X;
        public float Y;
        public float Width;
        public float Height;

#if DEBUG
        public override string ToString ()
        {
            var sb = new StringBuilder ("{Bitmap");

            sb.Append (" ; Name = ");
            sb.Append (Name);
            sb.Append (" ; BitmapName = ");
            sb.Append (BitmapName);
            sb.Append (" ; Opacity = ");
            sb.Append (Opacity);
            sb.Append (" ; X = ");
            sb.Append (X);
            sb.Append (" ; Y = ");
            sb.Append (Y);
            sb.Append (" ; Width = ");
            sb.Append (Width);
            sb.Append (" ; Height = ");
            sb.Append (Height);

            sb.Append ("}");
            return sb.ToString ();
        }
#endif
    }
    // ------------------------------------------------------------------------

    // ------------------------------------------------------------------------
    // TextBlock message
    // ------------------------------------------------------------------------
    sealed partial class TextBlock 
        :   IMessage
/*
        ,   IRenderable
*/        
    {
        public int MessageTypeId 
        { 
            get
            {
                return 15;
            }
        }

        public void Apply (IMessageVisitor messageVisitor)
        {
            messageVisitor.Visit (this);
        }
        
        public TextBlock (
                string name
            ,   string brush
            ,   float opacity
            ,   float x
            ,   float y
            ,   float width
            ,   float height
            ,   string fontFamily
            ,   float fontSize
            ,   string message
            )
        {
            this.Name = name;
            this.Brush = brush;
            this.Opacity = opacity;
            this.X = x;
            this.Y = y;
            this.Width = width;
            this.Height = height;
            this.FontFamily = fontFamily;
            this.FontSize = fontSize;
            this.Message = message;
        }

        public string Name;
        public string Brush;
        public float Opacity;
        public float X;
        public float Y;
        public float Width;
        public float Height;
        public string FontFamily;
        public float FontSize;
        public string Message;

#if DEBUG
        public override string ToString ()
        {
            var sb = new StringBuilder ("{TextBlock");

            sb.Append (" ; Name = ");
            sb.Append (Name);
            sb.Append (" ; Brush = ");
            sb.Append (Brush);
            sb.Append (" ; Opacity = ");
            sb.Append (Opacity);
            sb.Append (" ; X = ");
            sb.Append (X);
            sb.Append (" ; Y = ");
            sb.Append (Y);
            sb.Append (" ; Width = ");
            sb.Append (Width);
            sb.Append (" ; Height = ");
            sb.Append (Height);
            sb.Append (" ; FontFamily = ");
            sb.Append (FontFamily);
            sb.Append (" ; FontSize = ");
            sb.Append (FontSize);
            sb.Append (" ; Message = ");
            sb.Append (Message);

            sb.Append ("}");
            return sb.ToString ();
        }
#endif
    }
    // ------------------------------------------------------------------------

    // ------------------------------------------------------------------------
    // MoveTextBlock message
    // ------------------------------------------------------------------------
    sealed partial class MoveTextBlock 
        :   IMessage
/*
*/        
    {
        public int MessageTypeId 
        { 
            get
            {
                return 16;
            }
        }

        public void Apply (IMessageVisitor messageVisitor)
        {
            messageVisitor.Visit (this);
        }
        
        public MoveTextBlock (
                string name
            ,   float opacity
            ,   float x
            ,   float y
            )
        {
            this.Name = name;
            this.Opacity = opacity;
            this.X = x;
            this.Y = y;
        }

        public string Name;
        public float Opacity;
        public float X;
        public float Y;

#if DEBUG
        public override string ToString ()
        {
            var sb = new StringBuilder ("{MoveTextBlock");

            sb.Append (" ; Name = ");
            sb.Append (Name);
            sb.Append (" ; Opacity = ");
            sb.Append (Opacity);
            sb.Append (" ; X = ");
            sb.Append (X);
            sb.Append (" ; Y = ");
            sb.Append (Y);

            sb.Append ("}");
            return sb.ToString ();
        }
#endif
    }
    // ------------------------------------------------------------------------

    // ------------------------------------------------------------------------
    // LoadBitmapFromFile message
    // ------------------------------------------------------------------------
    sealed partial class LoadBitmapFromFile 
        :   IMessage
/*
        ,   IResource
*/        
    {
        public int MessageTypeId 
        { 
            get
            {
                return 17;
            }
        }

        public void Apply (IMessageVisitor messageVisitor)
        {
            messageVisitor.Visit (this);
        }
        
        public LoadBitmapFromFile (
                string name
            ,   string fileName
            )
        {
            this.Name = name;
            this.FileName = fileName;
        }

        public string Name;
        public string FileName;

#if DEBUG
        public override string ToString ()
        {
            var sb = new StringBuilder ("{LoadBitmapFromFile");

            sb.Append (" ; Name = ");
            sb.Append (Name);
            sb.Append (" ; FileName = ");
            sb.Append (FileName);

            sb.Append ("}");
            return sb.ToString ();
        }
#endif
    }
    // ------------------------------------------------------------------------

    // ------------------------------------------------------------------------
    // LoadBitmapFromUrl message
    // ------------------------------------------------------------------------
    sealed partial class LoadBitmapFromUrl 
        :   IMessage
/*
        ,   IResource
*/        
    {
        public int MessageTypeId 
        { 
            get
            {
                return 18;
            }
        }

        public void Apply (IMessageVisitor messageVisitor)
        {
            messageVisitor.Visit (this);
        }
        
        public LoadBitmapFromUrl (
                string name
            ,   string uRL
            )
        {
            this.Name = name;
            this.URL = uRL;
        }

        public string Name;
        public string URL;

#if DEBUG
        public override string ToString ()
        {
            var sb = new StringBuilder ("{LoadBitmapFromUrl");

            sb.Append (" ; Name = ");
            sb.Append (Name);
            sb.Append (" ; URL = ");
            sb.Append (URL);

            sb.Append ("}");
            return sb.ToString ();
        }
#endif
    }
    // ------------------------------------------------------------------------

    // ------------------------------------------------------------------------
    // SolidBrush message
    // ------------------------------------------------------------------------
    sealed partial class SolidBrush 
        :   IMessage
/*
        ,   IResource
*/        
    {
        public int MessageTypeId 
        { 
            get
            {
                return 19;
            }
        }

        public void Apply (IMessageVisitor messageVisitor)
        {
            messageVisitor.Visit (this);
        }
        
        public SolidBrush (
                string name
            ,   string color
            )
        {
            this.Name = name;
            this.Color = color;
        }

        public string Name;
        public string Color;

#if DEBUG
        public override string ToString ()
        {
            var sb = new StringBuilder ("{SolidBrush");

            sb.Append (" ; Name = ");
            sb.Append (Name);
            sb.Append (" ; Color = ");
            sb.Append (Color);

            sb.Append ("}");
            return sb.ToString ();
        }
#endif
    }
    // ------------------------------------------------------------------------

    // ------------------------------------------------------------------------
    // GradientBrush message
    // ------------------------------------------------------------------------
    sealed partial class GradientBrush 
        :   IMessage
/*
        ,   IResource
*/        
    {
        public int MessageTypeId 
        { 
            get
            {
                return 20;
            }
        }

        public void Apply (IMessageVisitor messageVisitor)
        {
            messageVisitor.Visit (this);
        }
        
        public GradientBrush (
                string name
            ,   string extendMode
            ,   string coordinateSpace
            ,   float x0
            ,   float y0
            ,   float x1
            ,   float y1
            )
        {
            this.Name = name;
            this.ExtendMode = extendMode;
            this.CoordinateSpace = coordinateSpace;
            this.X0 = x0;
            this.Y0 = y0;
            this.X1 = x1;
            this.Y1 = y1;
        }

        public string Name;
        public string ExtendMode;
        public string CoordinateSpace;
        public float X0;
        public float Y0;
        public float X1;
        public float Y1;

#if DEBUG
        public override string ToString ()
        {
            var sb = new StringBuilder ("{GradientBrush");

            sb.Append (" ; Name = ");
            sb.Append (Name);
            sb.Append (" ; ExtendMode = ");
            sb.Append (ExtendMode);
            sb.Append (" ; CoordinateSpace = ");
            sb.Append (CoordinateSpace);
            sb.Append (" ; X0 = ");
            sb.Append (X0);
            sb.Append (" ; Y0 = ");
            sb.Append (Y0);
            sb.Append (" ; X1 = ");
            sb.Append (X1);
            sb.Append (" ; Y1 = ");
            sb.Append (Y1);

            sb.Append ("}");
            return sb.ToString ();
        }
#endif
    }
    // ------------------------------------------------------------------------

    // ------------------------------------------------------------------------
    // CircularGradientBrush message
    // ------------------------------------------------------------------------
    sealed partial class CircularGradientBrush 
        :   IMessage
/*
        ,   IResource
*/        
    {
        public int MessageTypeId 
        { 
            get
            {
                return 21;
            }
        }

        public void Apply (IMessageVisitor messageVisitor)
        {
            messageVisitor.Visit (this);
        }
        
        public CircularGradientBrush (
                string name
            ,   string extendMode
            ,   float offsetX
            ,   float offsetY
            )
        {
            this.Name = name;
            this.ExtendMode = extendMode;
            this.OffsetX = offsetX;
            this.OffsetY = offsetY;
        }

        public string Name;
        public string ExtendMode;
        public float OffsetX;
        public float OffsetY;

#if DEBUG
        public override string ToString ()
        {
            var sb = new StringBuilder ("{CircularGradientBrush");

            sb.Append (" ; Name = ");
            sb.Append (Name);
            sb.Append (" ; ExtendMode = ");
            sb.Append (ExtendMode);
            sb.Append (" ; OffsetX = ");
            sb.Append (OffsetX);
            sb.Append (" ; OffsetY = ");
            sb.Append (OffsetY);

            sb.Append ("}");
            return sb.ToString ();
        }
#endif
    }
    // ------------------------------------------------------------------------

    // ------------------------------------------------------------------------
    // GradientStop message
    // ------------------------------------------------------------------------
    sealed partial class GradientStop 
        :   IMessage
/*
*/        
    {
        public int MessageTypeId 
        { 
            get
            {
                return 22;
            }
        }

        public void Apply (IMessageVisitor messageVisitor)
        {
            messageVisitor.Visit (this);
        }
        
        public GradientStop (
                string name
            ,   float position
            ,   string color
            )
        {
            this.Name = name;
            this.Position = position;
            this.Color = color;
        }

        public string Name;
        public float Position;
        public string Color;

#if DEBUG
        public override string ToString ()
        {
            var sb = new StringBuilder ("{GradientStop");

            sb.Append (" ; Name = ");
            sb.Append (Name);
            sb.Append (" ; Position = ");
            sb.Append (Position);
            sb.Append (" ; Color = ");
            sb.Append (Color);

            sb.Append ("}");
            return sb.ToString ();
        }
#endif
    }
    // ------------------------------------------------------------------------

    // ------------------------------------------------------------------------
    // Terminate message
    // ------------------------------------------------------------------------
    sealed partial class Terminate 
        :   IMessage
/*
*/        
    {
        public int MessageTypeId 
        { 
            get
            {
                return 23;
            }
        }

        public void Apply (IMessageVisitor messageVisitor)
        {
            messageVisitor.Visit (this);
        }
        
        public Terminate (
            )
        {
        }


#if DEBUG
        public override string ToString ()
        {
            var sb = new StringBuilder ("{Terminate");


            sb.Append ("}");
            return sb.ToString ();
        }
#endif
    }
    // ------------------------------------------------------------------------


    // ------------------------------------------------------------------------
    //
    // ------------------------------------------------------------------------
    namespace Interfaces
    {
    partial interface IMessageVisitor
    {
        void Visit (RemoveResource message);
        void Visit (RemoveAllResources message);
        void Visit (Remove message);
        void Visit (RemoveAll message);
        void Visit (WindowSize message);
        void Visit (WindowBackground message);
        void Visit (Line message);
        void Visit (Rectangle message);
        void Visit (RoundedRectangle message);
        void Visit (FilledRoundedRectangle message);
        void Visit (FilledRectangle message);
        void Visit (Ellipse message);
        void Visit (FilledEllipse message);
        void Visit (Bitmap message);
        void Visit (TextBlock message);
        void Visit (MoveTextBlock message);
        void Visit (LoadBitmapFromFile message);
        void Visit (LoadBitmapFromUrl message);
        void Visit (SolidBrush message);
        void Visit (GradientBrush message);
        void Visit (CircularGradientBrush message);
        void Visit (GradientStop message);
        void Visit (Terminate message);
    }
    }
    // ------------------------------------------------------------------------

    // ------------------------------------------------------------------------
    //
    // ------------------------------------------------------------------------
    partial class VisualizeForm
    {
        partial void ProcessMessage_RemoveResource (ref RemoveResource msg);

        partial void ProcessMessage_RemoveAllResources (ref RemoveAllResources msg);

        partial void ProcessMessage_Remove (ref Remove msg);

        partial void ProcessMessage_RemoveAll (ref RemoveAll msg);

        partial void ProcessMessage_WindowSize (ref WindowSize msg);

        partial void ProcessMessage_WindowBackground (ref WindowBackground msg);

        partial void ProcessMessage_Line (ref Line msg);

        partial void ProcessMessage_Rectangle (ref Rectangle msg);

        partial void ProcessMessage_RoundedRectangle (ref RoundedRectangle msg);

        partial void ProcessMessage_FilledRoundedRectangle (ref FilledRoundedRectangle msg);

        partial void ProcessMessage_FilledRectangle (ref FilledRectangle msg);

        partial void ProcessMessage_Ellipse (ref Ellipse msg);

        partial void ProcessMessage_FilledEllipse (ref FilledEllipse msg);

        partial void ProcessMessage_Bitmap (ref Bitmap msg);

        partial void ProcessMessage_TextBlock (ref TextBlock msg);

        partial void ProcessMessage_MoveTextBlock (ref MoveTextBlock msg);

        partial void ProcessMessage_LoadBitmapFromFile (ref LoadBitmapFromFile msg);

        partial void ProcessMessage_LoadBitmapFromUrl (ref LoadBitmapFromUrl msg);

        partial void ProcessMessage_SolidBrush (ref SolidBrush msg);

        partial void ProcessMessage_GradientBrush (ref GradientBrush msg);

        partial void ProcessMessage_CircularGradientBrush (ref CircularGradientBrush msg);

        partial void ProcessMessage_GradientStop (ref GradientStop msg);

        partial void ProcessMessage_Terminate (ref Terminate msg);

        public void ProcessMessage (IMessage message)
        {
            if (message == null)
            {
                return;
            }

            var messageTypeId = message.MessageTypeId;

            switch (messageTypeId)
            {
                case 1:
                    {
                        var msg = message as RemoveResource;
                        if (msg != null)
                        {
                            ProcessMessage_RemoveResource (ref msg);
                            
                            IsDirty ();
                        }
                    }
                    break;
                case 2:
                    {
                        var msg = message as RemoveAllResources;
                        if (msg != null)
                        {
                            ProcessMessage_RemoveAllResources (ref msg);
                            
                            IsDirty ();
                        }
                    }
                    break;
                case 3:
                    {
                        var msg = message as Remove;
                        if (msg != null)
                        {
                            ProcessMessage_Remove (ref msg);
                            
                            IsDirty ();
                        }
                    }
                    break;
                case 4:
                    {
                        var msg = message as RemoveAll;
                        if (msg != null)
                        {
                            ProcessMessage_RemoveAll (ref msg);
                            
                            IsDirty ();
                        }
                    }
                    break;
                case 5:
                    {
                        var msg = message as WindowSize;
                        if (msg != null)
                        {
                            ProcessMessage_WindowSize (ref msg);
                            
                            IsDirty ();
                        }
                    }
                    break;
                case 6:
                    {
                        var msg = message as WindowBackground;
                        if (msg != null)
                        {
                            ProcessMessage_WindowBackground (ref msg);
                            
                            IsDirty ();
                        }
                    }
                    break;
                case 7:
                    {
                        var msg = message as Line;
                        if (msg != null)
                        {
                            ProcessMessage_Line (ref msg);
                            
                            AddRenderable (msg.Name, msg);
                            
                            IsDirty ();
                        }
                    }
                    break;
                case 8:
                    {
                        var msg = message as Rectangle;
                        if (msg != null)
                        {
                            ProcessMessage_Rectangle (ref msg);
                            
                            AddRenderable (msg.Name, msg);
                            
                            IsDirty ();
                        }
                    }
                    break;
                case 9:
                    {
                        var msg = message as RoundedRectangle;
                        if (msg != null)
                        {
                            ProcessMessage_RoundedRectangle (ref msg);
                            
                            AddRenderable (msg.Name, msg);
                            
                            IsDirty ();
                        }
                    }
                    break;
                case 10:
                    {
                        var msg = message as FilledRoundedRectangle;
                        if (msg != null)
                        {
                            ProcessMessage_FilledRoundedRectangle (ref msg);
                            
                            AddRenderable (msg.Name, msg);
                            
                            IsDirty ();
                        }
                    }
                    break;
                case 11:
                    {
                        var msg = message as FilledRectangle;
                        if (msg != null)
                        {
                            ProcessMessage_FilledRectangle (ref msg);
                            
                            AddRenderable (msg.Name, msg);
                            
                            IsDirty ();
                        }
                    }
                    break;
                case 12:
                    {
                        var msg = message as Ellipse;
                        if (msg != null)
                        {
                            ProcessMessage_Ellipse (ref msg);
                            
                            AddRenderable (msg.Name, msg);
                            
                            IsDirty ();
                        }
                    }
                    break;
                case 13:
                    {
                        var msg = message as FilledEllipse;
                        if (msg != null)
                        {
                            ProcessMessage_FilledEllipse (ref msg);
                            
                            AddRenderable (msg.Name, msg);
                            
                            IsDirty ();
                        }
                    }
                    break;
                case 14:
                    {
                        var msg = message as Bitmap;
                        if (msg != null)
                        {
                            ProcessMessage_Bitmap (ref msg);
                            
                            AddRenderable (msg.Name, msg);
                            
                            IsDirty ();
                        }
                    }
                    break;
                case 15:
                    {
                        var msg = message as TextBlock;
                        if (msg != null)
                        {
                            ProcessMessage_TextBlock (ref msg);
                            
                            AddRenderable (msg.Name, msg);
                            
                            IsDirty ();
                        }
                    }
                    break;
                case 16:
                    {
                        var msg = message as MoveTextBlock;
                        if (msg != null)
                        {
                            ProcessMessage_MoveTextBlock (ref msg);
                            
                            IsDirty ();
                        }
                    }
                    break;
                case 17:
                    {
                        var msg = message as LoadBitmapFromFile;
                        if (msg != null)
                        {
                            ProcessMessage_LoadBitmapFromFile (ref msg);
                            
                            AddResource (msg.Name, msg);
                            
                            IsDirty ();
                        }
                    }
                    break;
                case 18:
                    {
                        var msg = message as LoadBitmapFromUrl;
                        if (msg != null)
                        {
                            ProcessMessage_LoadBitmapFromUrl (ref msg);
                            
                            AddResource (msg.Name, msg);
                            
                            IsDirty ();
                        }
                    }
                    break;
                case 19:
                    {
                        var msg = message as SolidBrush;
                        if (msg != null)
                        {
                            ProcessMessage_SolidBrush (ref msg);
                            
                            AddResource (msg.Name, msg);
                            
                            IsDirty ();
                        }
                    }
                    break;
                case 20:
                    {
                        var msg = message as GradientBrush;
                        if (msg != null)
                        {
                            ProcessMessage_GradientBrush (ref msg);
                            
                            AddResource (msg.Name, msg);
                            
                            IsDirty ();
                        }
                    }
                    break;
                case 21:
                    {
                        var msg = message as CircularGradientBrush;
                        if (msg != null)
                        {
                            ProcessMessage_CircularGradientBrush (ref msg);
                            
                            AddResource (msg.Name, msg);
                            
                            IsDirty ();
                        }
                    }
                    break;
                case 22:
                    {
                        var msg = message as GradientStop;
                        if (msg != null)
                        {
                            ProcessMessage_GradientStop (ref msg);
                            
                            IsDirty ();
                        }
                    }
                    break;
                case 23:
                    {
                        var msg = message as Terminate;
                        if (msg != null)
                        {
                            ProcessMessage_Terminate (ref msg);
                            
                            IsDirty ();
                        }
                    }
                    break;
                default:
                    break;
            }

        }
    }
    // ------------------------------------------------------------------------


}

namespace SBFastGraphics
{
    using Microsoft.SmallBasic.Library;
    using Internal;
    using Internal.Interfaces;

    // ------------------------------------------------------------------------
    /// <summary>
    /// FastWindow is used to draw graphics
    /// It's intended to faster and more flexible than the built in GraphicsWindow
    /// </summary>
    static partial class FastWindow
    {
        /// <summary>
        /// RemoveResource subroutine
        /// </summary>
        /// <param name="name">Should be convertible to a string</param>
        public static void RemoveResource (
                Primitive name
            )
        {
            var msg = new RemoveResource (
                    name
                );
            
            State.PostMessage (msg);
        }
        /// <summary>
        /// RemoveAllResources subroutine
        /// </summary>
        /// <param name="name">Should be convertible to a string</param>
        public static void RemoveAllResources (
                Primitive name
            )
        {
            var msg = new RemoveAllResources (
                    name
                );
            
            State.PostMessage (msg);
        }
        /// <summary>
        /// Remove subroutine
        /// </summary>
        /// <param name="name">Should be convertible to a string</param>
        public static void Remove (
                Primitive name
            )
        {
            var msg = new Remove (
                    name
                );
            
            State.PostMessage (msg);
        }
        /// <summary>
        /// RemoveAll subroutine
        /// </summary>
        /// <param name="name">Should be convertible to a string</param>
        public static void RemoveAll (
                Primitive name
            )
        {
            var msg = new RemoveAll (
                    name
                );
            
            State.PostMessage (msg);
        }
        /// <summary>
        /// WindowSize subroutine
        /// </summary>
        /// <param name="width">Should be convertible to a int</param>
        /// <param name="height">Should be convertible to a int</param>
        public static void WindowSize (
                Primitive width
            ,   Primitive height
            )
        {
            var msg = new WindowSize (
                    width
                ,   height
                );
            
            State.PostMessage (msg);
        }
        /// <summary>
        /// WindowBackground subroutine
        /// </summary>
        /// <param name="color">Should be convertible to a string</param>
        public static void WindowBackground (
                Primitive color
            )
        {
            var msg = new WindowBackground (
                    color
                );
            
            State.PostMessage (msg);
        }
        /// <summary>
        /// Line subroutine
        /// Creates a Renderable object
        /// </summary>
        /// <param name="name">Should be convertible to a string</param>
        /// <param name="brush">Should be convertible to a string</param>
        /// <param name="thickness">Should be convertible to a float</param>
        /// <param name="opacity">Should be convertible to a float</param>
        /// <param name="x0">Should be convertible to a float</param>
        /// <param name="y0">Should be convertible to a float</param>
        /// <param name="x1">Should be convertible to a float</param>
        /// <param name="y1">Should be convertible to a float</param>
        public static void Line (
                Primitive name
            ,   Primitive brush
            ,   Primitive thickness
            ,   Primitive opacity
            ,   Primitive x0
            ,   Primitive y0
            ,   Primitive x1
            ,   Primitive y1
            )
        {
            var msg = new Line (
                    name
                ,   brush
                ,   thickness
                ,   opacity
                ,   x0
                ,   y0
                ,   x1
                ,   y1
                );
            
            State.PostMessage (msg);
        }
        /// <summary>
        /// Rectangle subroutine
        /// Creates a Renderable object
        /// </summary>
        /// <param name="name">Should be convertible to a string</param>
        /// <param name="brush">Should be convertible to a string</param>
        /// <param name="opacity">Should be convertible to a float</param>
        /// <param name="x">Should be convertible to a float</param>
        /// <param name="y">Should be convertible to a float</param>
        /// <param name="width">Should be convertible to a float</param>
        /// <param name="height">Should be convertible to a float</param>
        /// <param name="thickness">Should be convertible to a float</param>
        public static void Rectangle (
                Primitive name
            ,   Primitive brush
            ,   Primitive opacity
            ,   Primitive x
            ,   Primitive y
            ,   Primitive width
            ,   Primitive height
            ,   Primitive thickness
            )
        {
            var msg = new Rectangle (
                    name
                ,   brush
                ,   opacity
                ,   x
                ,   y
                ,   width
                ,   height
                ,   thickness
                );
            
            State.PostMessage (msg);
        }
        /// <summary>
        /// RoundedRectangle subroutine
        /// Creates a Renderable object
        /// </summary>
        /// <param name="name">Should be convertible to a string</param>
        /// <param name="brush">Should be convertible to a string</param>
        /// <param name="opacity">Should be convertible to a float</param>
        /// <param name="x">Should be convertible to a float</param>
        /// <param name="y">Should be convertible to a float</param>
        /// <param name="width">Should be convertible to a float</param>
        /// <param name="height">Should be convertible to a float</param>
        /// <param name="radiusX">Should be convertible to a float</param>
        /// <param name="radiusY">Should be convertible to a float</param>
        /// <param name="thickness">Should be convertible to a float</param>
        public static void RoundedRectangle (
                Primitive name
            ,   Primitive brush
            ,   Primitive opacity
            ,   Primitive x
            ,   Primitive y
            ,   Primitive width
            ,   Primitive height
            ,   Primitive radiusX
            ,   Primitive radiusY
            ,   Primitive thickness
            )
        {
            var msg = new RoundedRectangle (
                    name
                ,   brush
                ,   opacity
                ,   x
                ,   y
                ,   width
                ,   height
                ,   radiusX
                ,   radiusY
                ,   thickness
                );
            
            State.PostMessage (msg);
        }
        /// <summary>
        /// FilledRoundedRectangle subroutine
        /// Creates a Renderable object
        /// </summary>
        /// <param name="name">Should be convertible to a string</param>
        /// <param name="brush">Should be convertible to a string</param>
        /// <param name="opacity">Should be convertible to a float</param>
        /// <param name="x">Should be convertible to a float</param>
        /// <param name="y">Should be convertible to a float</param>
        /// <param name="width">Should be convertible to a float</param>
        /// <param name="height">Should be convertible to a float</param>
        /// <param name="radiusX">Should be convertible to a float</param>
        /// <param name="radiusY">Should be convertible to a float</param>
        public static void FilledRoundedRectangle (
                Primitive name
            ,   Primitive brush
            ,   Primitive opacity
            ,   Primitive x
            ,   Primitive y
            ,   Primitive width
            ,   Primitive height
            ,   Primitive radiusX
            ,   Primitive radiusY
            )
        {
            var msg = new FilledRoundedRectangle (
                    name
                ,   brush
                ,   opacity
                ,   x
                ,   y
                ,   width
                ,   height
                ,   radiusX
                ,   radiusY
                );
            
            State.PostMessage (msg);
        }
        /// <summary>
        /// FilledRectangle subroutine
        /// Creates a Renderable object
        /// </summary>
        /// <param name="name">Should be convertible to a string</param>
        /// <param name="brush">Should be convertible to a string</param>
        /// <param name="opacity">Should be convertible to a float</param>
        /// <param name="x">Should be convertible to a float</param>
        /// <param name="y">Should be convertible to a float</param>
        /// <param name="width">Should be convertible to a float</param>
        /// <param name="height">Should be convertible to a float</param>
        public static void FilledRectangle (
                Primitive name
            ,   Primitive brush
            ,   Primitive opacity
            ,   Primitive x
            ,   Primitive y
            ,   Primitive width
            ,   Primitive height
            )
        {
            var msg = new FilledRectangle (
                    name
                ,   brush
                ,   opacity
                ,   x
                ,   y
                ,   width
                ,   height
                );
            
            State.PostMessage (msg);
        }
        /// <summary>
        /// Ellipse subroutine
        /// Creates a Renderable object
        /// </summary>
        /// <param name="name">Should be convertible to a string</param>
        /// <param name="brush">Should be convertible to a string</param>
        /// <param name="opacity">Should be convertible to a float</param>
        /// <param name="centerX">Should be convertible to a float</param>
        /// <param name="centerY">Should be convertible to a float</param>
        /// <param name="radiusX">Should be convertible to a float</param>
        /// <param name="radiusY">Should be convertible to a float</param>
        /// <param name="thickness">Should be convertible to a float</param>
        public static void Ellipse (
                Primitive name
            ,   Primitive brush
            ,   Primitive opacity
            ,   Primitive centerX
            ,   Primitive centerY
            ,   Primitive radiusX
            ,   Primitive radiusY
            ,   Primitive thickness
            )
        {
            var msg = new Ellipse (
                    name
                ,   brush
                ,   opacity
                ,   centerX
                ,   centerY
                ,   radiusX
                ,   radiusY
                ,   thickness
                );
            
            State.PostMessage (msg);
        }
        /// <summary>
        /// FilledEllipse subroutine
        /// Creates a Renderable object
        /// </summary>
        /// <param name="name">Should be convertible to a string</param>
        /// <param name="brush">Should be convertible to a string</param>
        /// <param name="opacity">Should be convertible to a float</param>
        /// <param name="centerX">Should be convertible to a float</param>
        /// <param name="centerY">Should be convertible to a float</param>
        /// <param name="radiusX">Should be convertible to a float</param>
        /// <param name="radiusY">Should be convertible to a float</param>
        public static void FilledEllipse (
                Primitive name
            ,   Primitive brush
            ,   Primitive opacity
            ,   Primitive centerX
            ,   Primitive centerY
            ,   Primitive radiusX
            ,   Primitive radiusY
            )
        {
            var msg = new FilledEllipse (
                    name
                ,   brush
                ,   opacity
                ,   centerX
                ,   centerY
                ,   radiusX
                ,   radiusY
                );
            
            State.PostMessage (msg);
        }
        /// <summary>
        /// Bitmap subroutine
        /// Creates a Renderable object
        /// </summary>
        /// <param name="name">Should be convertible to a string</param>
        /// <param name="bitmapName">Should be convertible to a string</param>
        /// <param name="opacity">Should be convertible to a float</param>
        /// <param name="x">Should be convertible to a float</param>
        /// <param name="y">Should be convertible to a float</param>
        /// <param name="width">Should be convertible to a float</param>
        /// <param name="height">Should be convertible to a float</param>
        public static void Bitmap (
                Primitive name
            ,   Primitive bitmapName
            ,   Primitive opacity
            ,   Primitive x
            ,   Primitive y
            ,   Primitive width
            ,   Primitive height
            )
        {
            var msg = new Bitmap (
                    name
                ,   bitmapName
                ,   opacity
                ,   x
                ,   y
                ,   width
                ,   height
                );
            
            State.PostMessage (msg);
        }
        /// <summary>
        /// TextBlock subroutine
        /// Creates a Renderable object
        /// </summary>
        /// <param name="name">Should be convertible to a string</param>
        /// <param name="brush">Should be convertible to a string</param>
        /// <param name="opacity">Should be convertible to a float</param>
        /// <param name="x">Should be convertible to a float</param>
        /// <param name="y">Should be convertible to a float</param>
        /// <param name="width">Should be convertible to a float</param>
        /// <param name="height">Should be convertible to a float</param>
        /// <param name="fontFamily">Should be convertible to a string</param>
        /// <param name="fontSize">Should be convertible to a float</param>
        /// <param name="message">Should be convertible to a string</param>
        public static void TextBlock (
                Primitive name
            ,   Primitive brush
            ,   Primitive opacity
            ,   Primitive x
            ,   Primitive y
            ,   Primitive width
            ,   Primitive height
            ,   Primitive fontFamily
            ,   Primitive fontSize
            ,   Primitive message
            )
        {
            var msg = new TextBlock (
                    name
                ,   brush
                ,   opacity
                ,   x
                ,   y
                ,   width
                ,   height
                ,   fontFamily
                ,   fontSize
                ,   message
                );
            
            State.PostMessage (msg);
        }
        /// <summary>
        /// MoveTextBlock subroutine
        /// </summary>
        /// <param name="name">Should be convertible to a string</param>
        /// <param name="opacity">Should be convertible to a float</param>
        /// <param name="x">Should be convertible to a float</param>
        /// <param name="y">Should be convertible to a float</param>
        public static void MoveTextBlock (
                Primitive name
            ,   Primitive opacity
            ,   Primitive x
            ,   Primitive y
            )
        {
            var msg = new MoveTextBlock (
                    name
                ,   opacity
                ,   x
                ,   y
                );
            
            State.PostMessage (msg);
        }
        /// <summary>
        /// LoadBitmapFromFile subroutine
        /// Creates a Resource object
        /// </summary>
        /// <param name="name">Should be convertible to a string</param>
        /// <param name="fileName">Should be convertible to a string</param>
        public static void LoadBitmapFromFile (
                Primitive name
            ,   Primitive fileName
            )
        {
            var msg = new LoadBitmapFromFile (
                    name
                ,   fileName
                );
            
            State.PostMessage (msg);
        }
        /// <summary>
        /// LoadBitmapFromUrl subroutine
        /// Creates a Resource object
        /// </summary>
        /// <param name="name">Should be convertible to a string</param>
        /// <param name="uRL">Should be convertible to a string</param>
        public static void LoadBitmapFromUrl (
                Primitive name
            ,   Primitive uRL
            )
        {
            var msg = new LoadBitmapFromUrl (
                    name
                ,   uRL
                );
            
            State.PostMessage (msg);
        }
        /// <summary>
        /// SolidBrush subroutine
        /// Creates a Resource object
        /// </summary>
        /// <param name="name">Should be convertible to a string</param>
        /// <param name="color">Should be convertible to a string</param>
        public static void SolidBrush (
                Primitive name
            ,   Primitive color
            )
        {
            var msg = new SolidBrush (
                    name
                ,   color
                );
            
            State.PostMessage (msg);
        }
        /// <summary>
        /// GradientBrush subroutine
        /// Creates a Resource object
        /// </summary>
        /// <param name="name">Should be convertible to a string</param>
        /// <param name="extendMode">Should be convertible to a string</param>
        /// <param name="coordinateSpace">Should be convertible to a string</param>
        /// <param name="x0">Should be convertible to a float</param>
        /// <param name="y0">Should be convertible to a float</param>
        /// <param name="x1">Should be convertible to a float</param>
        /// <param name="y1">Should be convertible to a float</param>
        public static void GradientBrush (
                Primitive name
            ,   Primitive extendMode
            ,   Primitive coordinateSpace
            ,   Primitive x0
            ,   Primitive y0
            ,   Primitive x1
            ,   Primitive y1
            )
        {
            var msg = new GradientBrush (
                    name
                ,   extendMode
                ,   coordinateSpace
                ,   x0
                ,   y0
                ,   x1
                ,   y1
                );
            
            State.PostMessage (msg);
        }
        /// <summary>
        /// CircularGradientBrush subroutine
        /// Creates a Resource object
        /// </summary>
        /// <param name="name">Should be convertible to a string</param>
        /// <param name="extendMode">Should be convertible to a string</param>
        /// <param name="offsetX">Should be convertible to a float</param>
        /// <param name="offsetY">Should be convertible to a float</param>
        public static void CircularGradientBrush (
                Primitive name
            ,   Primitive extendMode
            ,   Primitive offsetX
            ,   Primitive offsetY
            )
        {
            var msg = new CircularGradientBrush (
                    name
                ,   extendMode
                ,   offsetX
                ,   offsetY
                );
            
            State.PostMessage (msg);
        }
        /// <summary>
        /// GradientStop subroutine
        /// </summary>
        /// <param name="name">Should be convertible to a string</param>
        /// <param name="position">Should be convertible to a float</param>
        /// <param name="color">Should be convertible to a string</param>
        public static void GradientStop (
                Primitive name
            ,   Primitive position
            ,   Primitive color
            )
        {
            var msg = new GradientStop (
                    name
                ,   position
                ,   color
                );
            
            State.PostMessage (msg);
        }
    }
    // ------------------------------------------------------------------------
}
