﻿// ----------------------------------------------------------------------------------------------
// Copyright (c) fulesnabel@hotmail.se
// ----------------------------------------------------------------------------------------------
// This source code is subject to terms and conditions of the Microsoft Public License. A 
// copy of the license can be found in the License.html file at the root of this distribution. 
// If you cannot locate the  Microsoft Public License, please send an email to 
// dlr@microsoft.com. By using this source code in any fashion, you are agreeing to be bound 
//  by the terms of the Microsoft Public License.
// ----------------------------------------------------------------------------------------------
// You must not remove this notice, or any other, from this software.
// ----------------------------------------------------------------------------------------------


// ReSharper disable LoopCanBeConvertedToQuery

namespace SBFastGraphics.Internal
{
    using System.Diagnostics;
    using System.Globalization;

	static partial class Extensions
	{
  
        // --------------------------------------------------------------------
        // int
        // --------------------------------------------------------------------
        
        public static int Parse (this string s, int defaultValue = default (int))
        {
            if (s.IsNullOrEmpty ())
            {
                return defaultValue;
            }

            
            int value;
            return int.TryParse (s, NumberStyles.Integer, s_culture, out value)
                ?   value
                :   defaultValue
                ;
        }

        public static int DefaultTo (this int v, int defaultValue = default (int))
        {
            return v != default (int) ? v : defaultValue;
        }

        public static int DefaultTo (this int? v, int defaultValue = default (int))
        {
            return v != null ? v.Value : defaultValue;
        }

        public static int Clamp (this int v, int lowerBound, int higherBound)
        {
            Debug.Assert (lowerBound < higherBound);

            if (v < lowerBound)
            {
                return lowerBound;
            }
            if (v > higherBound)
            {
                return higherBound;
            }
            return v;
        }

        public static bool Between (this int v, int lowerBound, int higherBound)
        {
            Debug.Assert (lowerBound < higherBound);

            return v >= lowerBound & v <= higherBound;
        }

        public static bool In (
                this int v
            )
        {

            return false;
        }
        public static bool In (
                this int v
            ,   int in0
            )
        {
            if (v == in0)
            {
                return true;
            }

            return false;
        }
        public static bool In (
                this int v
            ,   int in0
            ,   int in1
            )
        {
            if (v == in0)
            {
                return true;
            }
            if (v == in1)
            {
                return true;
            }

            return false;
        }
        public static bool In (this int v, params int[] values)
        {
            foreach (var value in values)
            {
                if (v == value)
                {
                    return true;
                }
            }

            return false;
        }


        // --------------------------------------------------------------------
  
        // --------------------------------------------------------------------
        // long
        // --------------------------------------------------------------------
        
        public static long Parse (this string s, long defaultValue = default (long))
        {
            if (s.IsNullOrEmpty ())
            {
                return defaultValue;
            }

            
            long value;
            return long.TryParse (s, NumberStyles.Integer, s_culture, out value)
                ?   value
                :   defaultValue
                ;
        }

        public static long DefaultTo (this long v, long defaultValue = default (long))
        {
            return v != default (long) ? v : defaultValue;
        }

        public static long DefaultTo (this long? v, long defaultValue = default (long))
        {
            return v != null ? v.Value : defaultValue;
        }

        public static long Clamp (this long v, long lowerBound, long higherBound)
        {
            Debug.Assert (lowerBound < higherBound);

            if (v < lowerBound)
            {
                return lowerBound;
            }
            if (v > higherBound)
            {
                return higherBound;
            }
            return v;
        }

        public static bool Between (this long v, long lowerBound, long higherBound)
        {
            Debug.Assert (lowerBound < higherBound);

            return v >= lowerBound & v <= higherBound;
        }

        public static bool In (
                this long v
            )
        {

            return false;
        }
        public static bool In (
                this long v
            ,   long in0
            )
        {
            if (v == in0)
            {
                return true;
            }

            return false;
        }
        public static bool In (
                this long v
            ,   long in0
            ,   long in1
            )
        {
            if (v == in0)
            {
                return true;
            }
            if (v == in1)
            {
                return true;
            }

            return false;
        }
        public static bool In (this long v, params long[] values)
        {
            foreach (var value in values)
            {
                if (v == value)
                {
                    return true;
                }
            }

            return false;
        }


        // --------------------------------------------------------------------
	}
}
