// ----------------------------------------------------------------------------------------------
// Copyright (c) fulesnabel@hotmail.se
// ----------------------------------------------------------------------------------------------
// This source code is subject to terms and conditions of the Microsoft Public License. A 
// copy of the license can be found in the License.html file at the root of this distribution. 
// If you cannot locate the  Microsoft Public License, please send an email to 
// dlr@microsoft.com. By using this source code in any fashion, you are agreeing to be bound 
//  by the terms of the Microsoft Public License.
// ----------------------------------------------------------------------------------------------
// You must not remove this notice, or any other, from this software.
// ----------------------------------------------------------------------------------------------

// ReSharper disable InconsistentNaming

namespace SBFastGraphics.Internal
{
    using System;
    using System.Threading;
    using Interfaces;

    partial class State : BaseDisposable
    {
        readonly ConcurrentQueue<IMessage> m_shared_messageQueue = new ConcurrentQueue<IMessage> ();

        public State ()
        {
            Log.Info ("State created");

            m_render_thread = new Thread (Render_Start);
            m_render_thread.SetApartmentState (ApartmentState.STA);
            m_render_thread.Start ();
        }

        Thread m_render_thread;
        void Render_Start ()
        {
            try
            {
                Log.Info ("Render thread started");

                using (var render_form = new VisualizeForm (m_shared_messageQueue))
                {
                    var dialogResult = render_form.ShowDialog ();

                    Log.Info ("Render Form closed: {0}", dialogResult);
                }

            }
            catch (Exception exc) 
            {
                Log.Error ("Render thread crashed: {0}", exc);
            }            
        }

        protected override void OnDispose ()
        {
            Log.Info ("State disposed");

            m_shared_messageQueue.FlushAndTerminateQueue (new Terminate ());

            var thread = m_render_thread;
            m_render_thread = null;
            if (thread != null)
            {
                Log.Info ("Attempting peaceful shutdown of render thread");
                if (!thread.Join (1000))
                {
                    Log.Warning ("Peaceful shutdown of render thread failed, aborting it...");
                    thread.Abort ();
                }
            }
        }

        public void PostMessage (IMessage message)
        {
            m_shared_messageQueue.Enqueue (message);
        }
    }
}