﻿// ----------------------------------------------------------------------------------------------
// Copyright (c) fulesnabel@hotmail.se
// ----------------------------------------------------------------------------------------------
// This source code is subject to terms and conditions of the Microsoft Public License. A 
// copy of the license can be found in the License.html file at the root of this distribution. 
// If you cannot locate the  Microsoft Public License, please send an email to 
// dlr@microsoft.com. By using this source code in any fashion, you are agreeing to be bound 
//  by the terms of the Microsoft Public License.
// ----------------------------------------------------------------------------------------------
// You must not remove this notice, or any other, from this software.
// ----------------------------------------------------------------------------------------------

namespace SBTest
{
    using System;
    using System.Diagnostics;
    using System.Linq;
    using System.Threading;
    using SBFastGraphics;

    class Program
    {
        const string WhiteBrush = "WhiteBrush";
        const string BlackBrush = "BlackBrush";
        const string CircularBrush = "CircularBrush";
        const string YellowRaster = "YellowRaster";
        const string RedRaster = "RedRaster";
        const string GreenRaster = "GreenRaster";
        const string BitmapName = "BitmapName";

        static void Main (string[] args)
        {
            FastWindow.WindowSize (800, 600);
            FastWindow.WindowBackground ("#000040");


            var names = Enumerable
                .Range (0, 100)
                .Select (idx => new { Fill = "Fill" + idx, Outer = "Outer" + idx })
                .ToArray ()
                ;

            var phase = 0.0;

            //FastWindow.LoadBitmapFromUrl (BitmapName, "http://smallbasic.com/drop/soko/sokocutess.png");

            FastWindow.SolidBrush (WhiteBrush, "#FFFFFF");
            FastWindow.SolidBrush (BlackBrush, "#000000");

            FastWindow.GradientBrush (YellowRaster, "Clamp", "", 0, 0, 0, 1);
            FastWindow.GradientStop (YellowRaster, 0, "#000000");
            FastWindow.GradientStop (YellowRaster, 0.5, "#FFFF00");
            FastWindow.GradientStop (YellowRaster, 1, "#000000");

            FastWindow.GradientBrush (RedRaster, "Clamp", "", 0, 0, 0, 1);
            FastWindow.GradientStop (RedRaster, 0, "#000000");
            FastWindow.GradientStop (RedRaster, 0.5, "#FF0000");
            FastWindow.GradientStop (RedRaster, 1, "#000000");

            FastWindow.GradientBrush (GreenRaster, "Clamp", "", 0, 0, 0, 1);
            FastWindow.GradientStop (GreenRaster, 0, "#000000");
            FastWindow.GradientStop (GreenRaster, 0.5, "#00FF00");
            FastWindow.GradientStop (GreenRaster, 1, "#000000");

            FastWindow.CircularGradientBrush (CircularBrush, "Clamp", -0.25, -0.25);
            FastWindow.GradientStop (CircularBrush, 0, "#FF0000");
            FastWindow.GradientStop (CircularBrush, 1, "#FF0000FF");

            FastWindow.FilledEllipse ("SunEllipse", CircularBrush, 1, 100, 150, 100, 100);

            var stopwatch = new Stopwatch ();
            stopwatch.Start ();
            while (!Console.KeyAvailable)
            {
                var then = stopwatch.ElapsedMilliseconds;

                FastWindow.FilledRectangle ("Raster0", RedRaster, 1, 0, 300 + 100 * Math.Sin (6 * phase + 0.8), 800, 60);
                FastWindow.FilledRectangle ("Raster1", YellowRaster, 1, 0, 300 + 100 * Math.Sin (6 * phase + 0.4), 800, 60);
                FastWindow.FilledRectangle ("Raster2", GreenRaster, 1, 0, 300 + 100 * Math.Sin (6 * phase), 800, 60);

                for (var index = 0; index < names.Length; index++)
                {
                    var name = names[index];
                    var offset = index * 2 * Math.PI / (names.Length * 2);
                    var degree = phase + offset;
                    var scale = 100.0 * (2.0 * names.Length - index) / (2.0 * names.Length);
                    var centerX = scale * (Math.Cos (phase * 3) + 1.5) * Math.Sin (3 * degree) + 300;
                    var centerY = scale * (Math.Sin (phase * 4) + 1.5) * Math.Cos (4 * degree) + 300;

                    //FastWindow.Bitmap (name.Fill, BitmapName, 1, centerX, centerY, 51, 86);

                    FastWindow.FilledEllipse (name.Fill, CircularBrush, 1, centerX, centerY, 40, 40);
                    FastWindow.Ellipse (name.Outer, BlackBrush, 0.5, centerX, centerY, 40, 40, 4);
                }

                var diff = stopwatch.ElapsedMilliseconds - then;

                var millisecondsTimeout = (int)Math.Max (0L, 20 - diff);
                Thread.Sleep (millisecondsTimeout);

                phase += 0.01;
                phase %= 12 * 2 * Math.PI;
            }

            FastWindow.Terminate ();
        }
    }
}
